文字排版 - Bootstrap后台管理系统模版Ace下载
Description: 站长素材提供Bootstrap模版,Bootstrap教程,Bootstrap中文翻译等相关Bootstrap插件下载
Keywords: Bootstrap模版,Bootstrap模版下载,Bootstrap教程,Bootstrap中文

# Typography This is page-header (.page-header > h1)

#### Headings & Paragraphs

# h1. Heading 1

Vivamus sagittis lacus vel augue laoreet rutrum faucibus dolor auctor. Duis mollis, est non commodo luctus.

## h2. Heading 2

Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Donec ullamcorper nulla non metus auctor fringilla. Duis mollis, est non commodo luctus, nisi erat porttitor ligula, eget lacinia odio sem nec elit. Donec ullamcorper nulla non metus auctor fringilla.

### h3. Heading 3

Nullam quis risus eget urna mollis ornare vel eu leo. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Nullam id dolor id nibh ultricies vehicula.

#### h4. Heading 4

##### h5. Heading 5

###### h6. Heading 6

#### Lists

- Unordered List Item
- List Item in small tag
- List Item in bold tag
- List Item in italics tag
- - Nested List Item
  - Nested List Item
  - Nested List Item
- Unordered List Item which is a longer item and may break into more lines.
- List Item in strong tag
- List Item in emphasis tag

1. Ordered List Item
2. .text-primary Ordered List Item
3. .text-danger Ordered List Item
4. .text-success Ordered List Item
5. .text-warning Ordered List Item
6. .text-muted Ordered List Item

- List with custom icons and more space
- Unordered List Item # 2
- Unordered List Item # 3

- Even more space
- Unordered List Item # 5
- Unordered List Item # 6
- - Inline List Item # 1
  - List Item # 2
  - List Item # 3

#### BlockQuote & Address

> Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer posuere erat a ante.

> Someone famous Source Title

> Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer posuere erat a ante.

> Someone famous Source Title

#### Definition List

Horizontal
`<dl>`

Description lists
  A description list is perfect for defining terms.
Euismod
  Vestibulum id ligula porta felis euismod semper eget lacinia odio sem nec elit.
  Donec id elit non mi porta gravida at eget metus.
Malesuada porta
  Etiam porta sem malesuada magna mollis euismod.
Felis euismod semper eget lacinia
  Fusce dapibus, tellus ac cursus commodo, tortor mauris condimentum nibh, ut fermentum massa justo sit amet risus.

#### Code view

    <p class="muted">Fusce dapibus, tellus ac cursus commodo.</p>
    <p class="text-warning">Etiam porta sem malesuada.</p>
    <p class="text-error">Donec ullamcorper nulla non metus auctor fringilla.</p>
    <p class="text-info">Aenean eu leo quam.</p>
    <p class="text-success">Duis mollis.</p>

Choose Skin
Fixed Navbar
Fixed Sidebar
Fixed Breadcrumbs
Right To Left (rtl)
Inside .container